"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _runAssignValueAction = require("./runAssignValueAction");

var _test__ = require("./__test__");

var _output = require("./__test__/output");

var _actionTypes = require("../constants/actionTypes");

describe('runAssignValueAction', function () {
  it('sets the option set', function () {
    var _optionSets;

    var expected = 'id';
    var id = 'KmgWX65h0iM';
    var dataElement = _output.programStage.programStageDataElements[id];
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'true',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.SHOW_OPTION_GROUP,
      optionGroup: {
        id: expected
      }
    }, {
      stage: _output.programStage,
      optionSets: (_optionSets = {}, (0, _defineProperty2.default)(_optionSets, dataElement.optionSet, []), (0, _defineProperty2.default)(_optionSets, expected, []), _optionSets)
    });
    return expect(dataElement.optionSet).toEqual(expected);
  });
  it('hides the field', function () {
    var id = 'KmgWX65h0iM';
    var dataElement = _output.programStage.programStageDataElements[id];
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'true',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.HIDE_FIELD
    }, {
      stage: _output.programStage
    });
    return expect(dataElement.hide).toEqual(true);
  });
  it('shows the field', function () {
    var id = 'KmgWX65h0iM';
    var dataElement = _output.programStage.programStageDataElements[id];
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'false',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.HIDE_FIELD
    }, {
      stage: _output.programStage
    });
    return expect(dataElement.hide).toEqual(false);
  });
  it('assigns the value', function () {
    var id = 'KmgWX65h0iM';
    var expected = 'data';
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'true',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.ASSIGN,
      data: expected
    }, {
      stage: _output.programStage
    });
    return expect(_test__.values[id]).toEqual(expected);
  });
  it('sets the warning', function () {
    var id = 'KmgWX65h0iM';
    var expected = 'warning';
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'true',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.SHOW_WARNING,
      content: expected
    }, {
      stage: _output.programStage
    });
    return expect(_output.programStage.programStageDataElements[id].warning).toEqual(expected);
  });
  it('removes the warning', function () {
    var id = 'KmgWX65h0iM';
    var warning = 'warning';
    _output.programStage.programStageDataElements[id].warning = warning;
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'false',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.SHOW_WARNING,
      content: warning
    }, {
      stage: _output.programStage
    });
    return expect(_output.programStage.programStageDataElements[id].warning).toEqual(null);
  });
  it('sets the error', function () {
    var id = 'KmgWX65h0iM';
    var expected = 'error';
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'true',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.SHOW_ERROR,
      content: expected
    }, {
      stage: _output.programStage
    });
    return expect(_output.programStage.programStageDataElements[id].error).toEqual(expected);
  });
  it('removes the error', function () {
    var id = 'KmgWX65h0iM';
    var error = 'error';
    _output.programStage.programStageDataElements[id].error = error;
    (0, _runAssignValueAction.runAssignValueAction)(_test__.values, {
      condition: 'false',
      dataElement: {
        id: id
      },
      programRuleActionType: _actionTypes.SHOW_ERROR,
      content: error
    }, {
      stage: _output.programStage
    });
    return expect(_output.programStage.programStageDataElements[id].error).toEqual(null);
  });
});